<?php

/**
 * @package Joomla.Plugin
 * @subpackage Contact.HeptaContactPot
 *
 * @copyright (C) 2018 Open Source Matters, Inc. <https://www.joomla.org>
 * @license GNU General Public License version 2 or later; see LICENSE.txt
 */

use Joomla\CMS\Form\Form;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\Utilities\ArrayHelper;

/**
 * The Joomla Core confirm consent plugin
 *
 * @since  3.9.0
 */
class PlgContactHeptaContactPot extends CMSPlugin
{
    /**
     * @var    \Joomla\CMS\Application\SiteApplication
     *
     * @since  3.9.0
     */
    protected $app;

    /**
     * Load the language file on instantiation.
     *
     * @var    boolean
     */
    protected $autoloadLanguage = true;

    /**
     * Add additional fields to the supported forms
     *
     * @param   Form   $form  The form to be altered.
     * @param   mixed  $data  The associated data for the form.
     *
     * @return  boolean
     */
    public function onValidateContact($contact, $data)
    {
        $forbiddenWords = $this->params->get('forbidden_words', []);

        $forbiddenWords = array_filter(ArrayHelper::flatten(ArrayHelper::fromObject($forbiddenWords, true)));

        foreach ($forbiddenWords as $word) {
            $word = trim($word);

            if (empty($word)) {
                continue;
            }

            if (preg_match("/\b$word\b/i", $data['contact_message'], $matches)) {
                $reason = 'Matching ' . implode(', ', $matches);
                return $this->spamDetected($data, $reason);
            }
        }

        if (isset($data['phone_hepta']) && !empty($data['phone_hepta'])) {
            $reason = 'Filled honeypot field';
            return $this->spamDetected($data, $reason);
        }
    }

    /**
     * If SPAM is detected we throw an exception
     * @param String    $message
     */
    protected function spamDetected($data, string $reason)
    {
        $this->app->enqueueMessage(Text::_('PLG_HEPTACONTACT_MSG_MESSAGE_SENT'), 'success');
        return new Exception('Honeypot');
    }
}
